summaryrefslogtreecommitdiffstats
path: root/chromium/ui/events/event_constants.h
diff options
context:
space:
mode:
Diffstat (limited to 'chromium/ui/events/event_constants.h')
-rw-r--r--chromium/ui/events/event_constants.h46
1 files changed, 34 insertions, 12 deletions
diff --git a/chromium/ui/events/event_constants.h b/chromium/ui/events/event_constants.h
index 2a545b740ae..d2ff97c7aec 100644
--- a/chromium/ui/events/event_constants.h
+++ b/chromium/ui/events/event_constants.h
@@ -23,7 +23,6 @@ enum EventType {
ET_TOUCH_RELEASED,
ET_TOUCH_PRESSED,
ET_TOUCH_MOVED,
- ET_TOUCH_STATIONARY,
ET_TOUCH_CANCELLED,
ET_DROP_TARGET_EVENT,
ET_TRANSLATED_KEY_PRESS,
@@ -31,29 +30,37 @@ enum EventType {
// GestureEvent types
ET_GESTURE_SCROLL_BEGIN,
+ ET_GESTURE_TYPE_START = ET_GESTURE_SCROLL_BEGIN,
ET_GESTURE_SCROLL_END,
ET_GESTURE_SCROLL_UPDATE,
ET_GESTURE_TAP,
ET_GESTURE_TAP_DOWN,
ET_GESTURE_TAP_CANCEL,
- ET_GESTURE_BEGIN, // Sent before any other gesture types.
- ET_GESTURE_END, // Sent after any other gestures.
+ ET_GESTURE_TAP_UNCONFIRMED, // User tapped, but the tap delay hasn't expired.
+ ET_GESTURE_DOUBLE_TAP,
+ ET_GESTURE_BEGIN, // The first event sent when each finger is pressed.
+ ET_GESTURE_END, // Sent for each released finger.
ET_GESTURE_TWO_FINGER_TAP,
ET_GESTURE_PINCH_BEGIN,
ET_GESTURE_PINCH_END,
ET_GESTURE_PINCH_UPDATE,
ET_GESTURE_LONG_PRESS,
ET_GESTURE_LONG_TAP,
- // A SWIPE gesture can happen at the end of a TAP_UP gesture if the
- // finger(s) were moving quickly before they are released.
- ET_GESTURE_MULTIFINGER_SWIPE,
+ // A SWIPE gesture can happen at the end of a touch sequence involving one or
+ // more fingers if the finger velocity was high enough when the first finger
+ // was released.
+ ET_GESTURE_SWIPE,
ET_GESTURE_SHOW_PRESS,
+ // Sent by Win8+ metro when the user swipes from the bottom or top.
+ ET_GESTURE_WIN8_EDGE_SWIPE,
+
// Scroll support.
// TODO[davemoore] we need to unify these events w/ touch and gestures.
ET_SCROLL,
ET_SCROLL_FLING_START,
ET_SCROLL_FLING_CANCEL,
+ ET_GESTURE_TYPE_END = ET_SCROLL_FLING_CANCEL,
// Sent by the system to indicate any modal type operations, such as drag and
// drop or menus, should stop.
@@ -78,19 +85,34 @@ enum EventFlags {
EF_LEFT_MOUSE_BUTTON = 1 << 4,
EF_MIDDLE_MOUSE_BUTTON = 1 << 5,
EF_RIGHT_MOUSE_BUTTON = 1 << 6,
- EF_COMMAND_DOWN = 1 << 7, // Only useful on OSX
+ EF_COMMAND_DOWN = 1 << 7, // GUI Key (e.g. Command on OS X keyboards,
+ // Search on Chromebook keyboards,
+ // Windows on MS-oriented keyboards)
EF_EXTENDED = 1 << 8, // Windows extended key (see WM_KEYDOWN doc)
EF_IS_SYNTHESIZED = 1 << 9,
EF_ALTGR_DOWN = 1 << 10,
+ EF_MOD3_DOWN = 1 << 11,
+};
+
+// Flags specific to key events
+enum KeyEventFlags {
+ EF_NUMPAD_KEY = 1 << 16, // Key originates from number pad (Xkb only)
+ EF_IME_FABRICATED_KEY = 1 << 17, // Key event fabricated by the underlying
+ // IME without a user action.
+ // (Linux X11 only)
+ EF_IS_REPEAT = 1 << 18,
+ EF_FUNCTION_KEY = 1 << 19, // Key originates from function key row
};
// Flags specific to mouse events
enum MouseEventFlags {
- EF_IS_DOUBLE_CLICK = 1 << 16,
- EF_IS_TRIPLE_CLICK = 1 << 17,
- EF_IS_NON_CLIENT = 1 << 18,
- EF_FROM_TOUCH = 1 << 19, // Indicates this mouse event is generated
- // from an unconsumed touch/gesture event.
+ EF_IS_DOUBLE_CLICK = 1 << 16,
+ EF_IS_TRIPLE_CLICK = 1 << 17,
+ EF_IS_NON_CLIENT = 1 << 18,
+ EF_FROM_TOUCH = 1 << 19, // Indicates this mouse event is generated
+ // from an unconsumed touch/gesture event.
+ EF_TOUCH_ACCESSIBILITY = 1 << 20, // Indicates this event was generated from
+ // touch accessibility mode.
};
// Result of dispatching an event.